@@ -184,7 +184,8 @@ def run():
     # Author dictionary
     author_dict = {'Alias': 'rly0nheart',
                                          'Country': 'Zambia, Africa',
-                                         'About.me': 'https://about.me/rly0nheart'}
+                                         'About.me': 'https://about.me/rly0nheart',
+                                         'BuyMeACoffee': 'https://buymeacoffee.com/189381184'}
                                          
                                          
                                          
@@ -239,16 +240,16 @@ def run():
             elif command_input == 'help':
             	print(help())
             elif command_input == 'exit':
-            	logging.info('Session terminated with \'exit\' command.')
-            	exit(f'\n{colors.white}[{colors.green} ! {colors.white}] Session closed with {colors.white_bg}exit{colors.reset}{colors.white} command.{colors.reset}')
+            	logging.info('Session terminated with (exit) command.')
+            	exit(f'\n{colors.white}[{colors.green} ! {colors.white}] Session closed with ({colors.green}exit{colors.reset}{colors.white}) command.{colors.reset}')
             else:
             	pass
                     
-            input(f'\n{colors.white}[{colors.green} ? {colors.white}] Press {colors.white_bg}any key{colors.reset}{colors.white} to continue{colors.reset} ')
+            input(f'\n{colors.white}[{colors.green} ? {colors.white}] Press any key to continue{colors.reset} ')
                             
         except KeyboardInterrupt:
-            logging.info('Process interrupted with Ctrl+C')
-            exit(f'\n{colors.white}[{colors.red}x{colors.white}] Process interrupted with {colors.red_bg}Ctrl+C{colors.reset}')
+            logging.info('Session terminated with (Ctrl+C).')
+            exit(f'\n{colors.white}[{colors.red} x {colors.white}] Session terminated with ({colors.red}Ctrl{colors.white}+{colors.red}C{colors.reset}{colors.white}).{colors.reset}')
             
         except Exception as e:
             logging.error(f'Session terminated on error: {e}')
@@ -256,11 +257,11 @@ def run():
                    
             
 def org_info(org_attrs, org_attr_dict):
-    organization = input(f'\n{colors.white}[{colors.white_bg}@Organization{colors.reset}{colors.white}] (username){colors.reset} ')
+    organization = input(f'\n{colors.white}--> @{colors.green}organization{colors.white} (username){colors.reset} ')
     api = f'https://api.github.com/orgs/{organization}'
     response = requests.get(api)
     if response.status_code != 200:
-    	print(f'\n{colors.white}[{colors.red}-{colors.white}] Organization @{organization}{colors.red_bg}Not Found{colors.reset}')
+    	print(f'\n{colors.white}[{colors.red} - {colors.white}] Organization ({organization}) not found..{colors.reset}')
     else:
     	response = response.json()
     	print(f"\n{colors.white}{response['name']}{colors.reset}")
@@ -270,11 +271,11 @@ def org_info(org_attrs, org_attr_dict):
                         
 # Fetching user information        
 def user_profile(profile_attrs, profile_attr_dict):
-    username = input(f'\n{colors.white}[{colors.white_bg}@Username{colors.reset}{colors.white}]{colors.reset} ')
+    username = input(f'\n{colors.white}--> @{colors.green}username{colors.reset} ')
     api = f'https://api.github.com/users/{username}'
     response = requests.get(api)
     if response.status_code != 200:
-    	print(f'\n{colors.white}[{colors.red} - {colors.white}] User @{username} {colors.red_bg}Not Found{colors.reset}')
+    	print(f'\n{colors.white}[{colors.red} - {colors.white}] User ({username}) not found.{colors.reset}')
     else:
     	response = response.json()
     	print(f"\n{colors.white}{response['name']}{colors.reset}")
@@ -284,12 +285,12 @@ def user_profile(profile_attrs, profile_attr_dict):
         	        	
 # Fetching repository information   	
 def repo_info(repo_attrs, repo_attr_dict):
-    repo_name = input(f'\n{colors.white}[{colors.white_bg}%reponame{colors.reset}{colors.white}]{colors.reset} ')
-    username = input(f'{colors.white}[{colors.white_bg}@Owner{colors.reset}{colors.white}] (username){colors.reset} ')
+    repo_name = input(f'\n{colors.white}--> %{colors.green}reponame{colors.reset} ')
+    username = input(f'{colors.white}--> @{colors.green}owner{colors.white} (username){colors.reset} ')
     api = f'https://api.github.com/repos/{username}/{repo_name}'
     response = requests.get(api)
     if response.status_code != 200:
-    	print(f'\n{colors.white}[{colors.red}-{colors.white}] Repository %{repo_name} or user @{username} {colors.red}Not Found{colors.reset}')
+    	print(f'\n{colors.white}[{colors.red} - {colors.white}] Repository ({repo_name}) or user ({username}) not found.{colors.reset}')
     else:
     	response = response.json()
     	print(f"\n{colors.white}{response['full_name']}{colors.reset}")
@@ -299,13 +300,13 @@ def repo_info(repo_attrs, repo_attr_dict):
     
 # Get path contents        
 def path_contents(path_attrs, path_attr_dict):
-    repo_name = input(f'\n{colors.white}[{colors.white_bg}%reponame{colors.reset}{colors.white}]{colors.reset} ')
-    username = input(f'{colors.white}[{colors.white_bg}@Owner{colors.reset}{colors.white}] (username){colors.reset} ')
-    path_name = input(f'{colors.white}[{colors.white_bg}/path/name{colors.reset}{colors.white}]{colors.reset} ')
+    repo_name = input(f'\n{colors.white}--> %{colors.green}reponame{colors.reset} ')
+    username = input(f'{colors.white}--> @{colors.green}owner{colors.white} (username){colors.reset} ')
+    path_name = input(f'{colors.white}--> ~{colors.green}/path/name{colors.reset} ')
     api = f'https://api.github.com/repos/{username}/{repo_name}/contents/{path_name}'
     response = requests.get(api)
     if response.status_code != 200:
-        print(f'\n{colors.white}[{colors.red} - {colors.white}] Information {colors.red_bg}Not Found{colors.reset}')
+        print(f'\n{colors.white}[{colors.red} - {colors.white}] Information not found.{colors.reset}')
     else:
     	response = response.json()
     	for item in response:
@@ -316,11 +317,11 @@ def path_contents(path_attrs, path_attr_dict):
    
 # Fetching organozation repositories        
 def org_repos(repo_attrs, repo_attr_dict):
-    organization = input(f'\n{colors.white}[{colors.white_bg}@Organization{colors.reset}{colors.white}] (username){colors.reset} ')
+    organization = input(f'\n{colors.white}--> @{colors.green}organization{colors.white} (username){colors.reset} ')
     api = f'https://api.github.com/orgs/{organization}/repos?per_page=100'
     response = requests.get(api)
     if response.status_code != 200:
-        print(f'\n{colors.white}[{colors.red} - {colors.white}] Organization @{organization} {colors.red_bg}Not Found{colors.reset}')
+        print(f'\n{colors.white}[{colors.red} - {colors.white}] Organization ({organization}) not found.{colors.reset}')
     else:
         response = response.json()
         for repo in response:
@@ -332,11 +333,11 @@ def org_repos(repo_attrs, repo_attr_dict):
    
 # Fetching user repositories        
 def user_repos(repo_attrs, repo_attr_dict):
-    username = input(f'\n{colors.white}[{colors.white_bg}@Username{colors.reset}{colors.white}]{colors.reset} ')
+    username = input(f'\n{colors.white}--> @{colors.green}username{colors.reset} ')
     api = f'https://api.github.com/users/{username}/repos?per_page=100'
     response = requests.get(api)
     if response.status_code != 200:
-    	print(f'\n{colors.white}[{colors.red} - {colors.white}] User @{username} {colors.red_bg}Not Found{colors.reset}')
+    	print(f'\n{colors.white}[{colors.red} - {colors.white}] User ({username}) not found.{colors.reset}')
     else:
     	response = response.json()
     	for repo in response:
@@ -348,13 +349,13 @@ def user_repos(repo_attrs, repo_attr_dict):
     	   	       	    
 # Fetching user's gists
 def user_gists(gists_attrs, gists_attr_dict):
-    username = input(f'\n{colors.white}[{colors.white_bg}@Username{colors.reset}{colors.white}]{colors.reset} ')
+    username = input(f'\n{colors.white}--> @{colors.green}username{colors.reset} ')
     api = f'https://api.github.com/users/{username}/gists'
     response = requests.get(api).json()
     if response == []:
-    	print(f'\n{colors.white}[{colors.red} - {colors.white}] User @{username} {colors.red_bg}does not{colors.reset}{colors.white} have any active gists.{colors.reset}')
-    elif "Not Found" in response['message']:
-    	print(f'\n{colors.white}[{colors.red} - {colors.white}] User @{username} {colors.red_bg}Not Found{colors.reset}')
+    	print(f'\n{colors.white}[{colors.red} - {colors.white}] User ({username}) does not have any active gists.{colors.reset}')
+    elif "not found." in response['message']:
+    	print(f'\n{colors.white}[{colors.red} - {colors.white}] User ({username}) not found.{colors.reset}')
     else:
         for item in response:
         	print(f"\n{colors.white}{item['id']}{colors.reset}")
@@ -365,13 +366,13 @@ def user_gists(gists_attrs, gists_attr_dict):
     	    	    
 # Fetching user's followera'    	    
 def followers(user_attrs, user_attr_dict):
-    username = input(f'\n{colors.white}[{colors.white_bg}@Username{colors.reset}{colors.white}]{colors.reset} ')
+    username = input(f'\n{colors.white}--> @{colors.green}username{colors.reset} ')
     api = f'https://api.github.com/users/{username}/followers?per_page=100'
     response = requests.get(api).json()
     if response == []:
-    	print(f'\n{colors.white}[{colors.red} - {colors.white}]User @{username} {colors.red_bg}does not{colors.reset}{colors.white} have followers.{colors.reset}')
-    elif "Not Found" in response['message']:
-    	print(f'\n{colors.white}[{colors.red} - {colors.white}] User @{username} {colors.red_bg}Not Found{colors.reset}')
+    	print(f'\n{colors.white}[{colors.red} - {colors.white}]User ({username}) does not have followers.{colors.reset}')
+    elif "not found." in response['message']:
+    	print(f'\n{colors.white}[{colors.red} - {colors.white}] User ({username}) not found.{colors.reset}')
     else:
         for item in response:
         	print(f"\n{colors.white}@{item['login']}{colors.reset}")
@@ -382,19 +383,19 @@ def followers(user_attrs, user_attr_dict):
                     
 # Checking whether or not user[A] follows user[B]            
 def following():
-    user_a = input(f'\n{colors.white}[{colors.white_bg}@User A{colors.reset}{colors.white}] (username){colors.reset} ')
-    user_b = input(f'{colors.white}[{colors.white_bg}@User B{colors.reset}{colors.white}] (username){colors.reset} ')
+    user_a = input(f'\n{colors.white}--> @{colors.green}user{colors.white}[A] (username){colors.reset} ')
+    user_b = input(f'{colors.white}--> @{colors.green}user{colors.white}[B] (username){colors.reset} ')
     api = f'https://api.github.com/users/{user_a}/following/{user_b}'
     response = requests.get(api)
     if response.status_code == 204:
-    	print(f'\n{colors.white}[{colors.green} + {colors.white}] @{user_a} {colors.green_bg}follows{colors.reset}{colors.white} @{user_b}.{colors.reset}')
+    	print(f'\n{colors.white}[{colors.green} + {colors.white}] @{user_a} follows @{user_b}.{colors.reset}')
     else:
-    	print(f'\n{colors.white}[{colors.red} - {colors.white}] @{user_a} {colors.red_bg}does not{colors.reset}{colors.white} follow @{user_b}.{colors.reset}')             
+    	print(f'\n{colors.white}[{colors.red} - {colors.white}] @{user_a} does not follow @{user_b}.{colors.reset}')             
 
     	           	    
 # User search    	    
 def user_search(user_attrs, user_attr_dict):
-    query = input(f'\n{colors.white}[{colors.white_bg}#@Query{colors.reset}{colors.white}]{colors.reset} ')
+    query = input(f'\n{colors.white}--> @{colors.green}query{colors.white} (eg. john){colors.reset} ')
     api = f'https://api.github.com/search/users?q={query}&per_page=100'
     response = requests.get(api).json()
     for item in response['items']:
@@ -406,7 +407,7 @@ def user_search(user_attrs, user_attr_dict):
        		
 # Repository search
 def repo_search(repo_attrs, repo_attr_dict):
-    query = input(f'\n{colors.white}[{colors.white_bg}#%Query{colors.reset}{colors.white}]{colors.reset} ')
+    query = input(f'\n{colors.white}--> %{colors.green}query{colors.white} (eg. git){colors.reset} ')
     api = f'https://api.github.com/search/repositories?q={query}&per_page=100'
     response = requests.get(api).json()
     for item in response['items']:
@@ -418,7 +419,7 @@ def repo_search(repo_attrs, repo_attr_dict):
     
 # Topics search
 def topic_search(topic_attrs, topic_attr_dict):
-    query = input(f'\n{colors.white}[{colors.white_bg}##Query{colors.reset}{colors.white}]{colors.reset} ')
+    query = input(f'\n{colors.white}--> #{colors.green}query{colors.white} (eg. osint){colors.reset} ')
     api = f'https://api.github.com/search/topics?q={query}&per_page=100'
     response = requests.get(api).json()
     for item in response['items']:
@@ -430,7 +431,7 @@ def topic_search(topic_attrs, topic_attr_dict):
     
 # Issue search
 def issue_search(issue_attrs, issue_attr_dict):
-    query = input(f'\n{colors.white}[{colors.white_bg}#!Query{colors.reset}{colors.white}]{colors.reset} ')
+    query = input(f'\n{colors.white}--> !{colors.green}query{colors.white} (eg. error){colors.reset} ')
     api = f'https://api.github.com/search/issues?q={query}&per_page=100'
     response = requests.get(api).json()
     for item in response['items']:
@@ -442,7 +443,7 @@ def issue_search(issue_attrs, issue_attr_dict):
     
 # Commits search
 def commits_search():
-    query = input(f'\n{colors.white}[{colors.white_bg}#:Query{colors.reset}{colors.white}]{colors.reset} ')
+    query = input(f'\n{colors.white}--> :{colors.green}query{colors.white} (eg. filename:index.php){colors.reset} ')
     api = f'https://api.github.com/search/commits?q={query}&per_page=100'
     response = requests.get(api).json()
     number=0
@@ -464,7 +465,7 @@ def view_logs():
 
 # Delete a specified log file
 def delete_log():
-    log_file = input(f"\n{colors.white}[{colors.white_bg}logfile{colors.reset}{colors.white}]{colors.reset} ")
+    log_file = input(f"\n{colors.white}--> logfile (eg. 2022-04-27 10:09:36.068312.log){colors.reset} ")
     if sys.platform.lower().startswith(('win','darwin')):
         subprocess.run(['del',f'{os.getcwd()}/.logs/{log_file}'])
     else:
@@ -476,7 +477,7 @@ def delete_log():
 
 # Read a specified log file    	
 def read_log():
-    log_file = input(f"\n{colors.white}[{colors.white_bg}logfile{colors.reset}{colors.white}]{colors.reset} ")
+    log_file = input(f"\n{colors.white}--> logfile (eg. 2022-04-27 10:09:36.068312.log){colors.reset} ")
     with open(f'.logs/{log_file}', 'r') as log:
         logging.info(f'Reading log file: {log_file}')
         print("\n"+log.read())
@@ -487,13 +488,9 @@ def changelog():
     # lol yes the changelog is hard coded
     changelog_text = f'''
     
-  {colors.red_bg}v1.7.0-dev [CHANGELOG]{colors.reset}
-  • Changed (y/n) behavior in color chooser (where any input apart from 'y' was considered as 'n')
-  • Added 'logs:view' command for viewing octosuite logs
-  • Added 'logs:read' command for reading a specified log file
-  • Added 'logs:delete' command for deleting a specified log file
-  • Minor improvements
-  {colors.red_bg}                      {colors.reset}'''
+  {colors.red_bg} {banner.version} [CHANGELOG] {colors.reset}
+   • Minor bug fixes and improvements
+  {colors.red_bg}                    {colors.reset}'''
     return changelog_text
     	
     	
